@@ -88,45 +88,3 @@ print_step_forward <- function(data) {
 }
 
 
-print_norm_test <- function(data) {
-
-  # width
-  w1 <- 18
-  w2 <- 14
-  w3 <- 7
-  w <- sum(w1, w2, w3, 8)
-
-  # vectors
-  tests <- c(
-    "Shapiro-Wilk", "Kolmogorov-Smirnov", "Cramer-von Mises",
-    "Anderson-Darling"
-  )
-  stats <- c(
-    data$shapiro$statistic, data$kolmogorv$statistic,
-    data$cramer$statistic, data$anderson$statistic
-  )
-  pvals <- c(
-    data$shapiro$p.value, data$kolmogorv$p.value,
-    data$cramer$p.value, data$anderson$p.value
-  )
-  n <- length(stats)
-
-  # print
-
-  cat(paste("Hint:", "If pvalue > 0.05, data is normally distributed.", sep="\n", "\n"))
-
-  cat(rep("-", w), sep = "", "\n")
-  cat(
-    format("Test", width = w1, justify = "centre"), fs(), format("Statistic", width = w2, justify = "centre"),
-    fs(), format("pvalue", width = 7, justify = "centre"), "\n"
-  )
-  cat(rep("-", w), sep = "", "\n")
-  for (i in seq_len(n)) {
-    cat(
-      format(tests[i], width = w1), fs(), format(as.character(round(stats[i], 4)), width = w2, justify = "centre"),
-      fs(), format(round(pvals[i], 4), nsmall = 4, width = 7, justify = "centre"), "\n"
-    )
-  }
-  cat(rep("-", w), sep = "", "\n")
-}
-
